@@ -31,7 +31,7 @@ class Attachment(models.Model):
     objects = AttachmentManager()
 
     content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
-    object_id = models.TextField()
+    object_id = models.TextField(db_index=True)
     content_object = GenericForeignKey("content_type", "object_id")
     creator = models.ForeignKey(
         settings.AUTH_USER_MODEL,
@@ -42,8 +42,8 @@ class Attachment(models.Model):
     attachment_file = models.FileField(
         _("attachment"), upload_to=attachment_upload
     )
-    created = models.DateTimeField(_("created"), auto_now_add=True)
-    modified = models.DateTimeField(_("modified"), auto_now=True)
+    created = models.DateTimeField(_("created"), auto_now_add=True, db_index=True)
+    modified = models.DateTimeField(_("modified"), auto_now=True, db_index=True)
 
     class Meta:
         verbose_name = _("attachment")
@@ -62,3 +62,25 @@ class Attachment(models.Model):
     @property
     def filename(self):
         return os.path.split(self.attachment_file.name)[1]
+
+    def attach_to(self, new_object, update_path=False):
+        """
+            Attach to a new object and possibly move the actual file on disk!
+
+            .. important::
+
+                As long as path names are valid you can continue serving
+                the files from their original path and not change it!
+        """
+        self.object_id = new_object.pk
+        self.content_type = ContentType.objects.get_for_model(new_object)
+        self.save()
+
+        if update_path:
+            old_path = self.attachment_file.path
+            self.attachment_file.name = attachment_upload(self, self.filename)
+            self.attachment_file.save()
+
+            os.makedirs(
+                os.path.dirname(self.attachment_file.path), exist_ok=True)
+            os.rename(old_path, self.attachment_file.path)
